@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2012 The Project Lombok Authors.
+ * Copyright (C) 2009-2017 The Project Lombok Authors.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -22,15 +22,13 @@
 package lombok.patcher;
 
 import java.io.ByteArrayOutputStream;
+import java.io.IOException;
 import java.io.InputStream;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
 
-import lombok.Cleanup;
-import lombok.Getter;
-
 import org.objectweb.asm.AnnotationVisitor;
 import org.objectweb.asm.Attribute;
 import org.objectweb.asm.ClassReader;
@@ -141,8 +139,9 @@ public abstract class PatchScript {
 	}
 	
 	private static byte[] readStream(String resourceName) {
+		InputStream wrapStream = null;
 		try {
-			@Cleanup InputStream wrapStream = PatchScript.class.getResourceAsStream(resourceName);
+			wrapStream = PatchScript.class.getResourceAsStream(resourceName);
 			ByteArrayOutputStream baos = new ByteArrayOutputStream();
 			byte[] b = new byte[65536];
 			while (true) {
@@ -154,12 +153,16 @@ public abstract class PatchScript {
 			return baos.toByteArray();
 		} catch (Exception e) {
 			throw new IllegalArgumentException("resource " + resourceName + " does not exist.", e);
+		} finally {
+			if (wrapStream != null) try {
+				wrapStream.close();
+			} catch (IOException ignore) {}
 		}
 	}
 	
 	private static abstract class NoopClassVisitor extends ClassVisitor {
 		public NoopClassVisitor() {
-			super(Opcodes.ASM4);
+			super(Opcodes.ASM6);
 		}
 		
 		public void visit(int version, int access, String name, String signature, String superName, String[] interfaces) {}
@@ -205,7 +208,7 @@ public abstract class PatchScript {
 
 	private static final class InsertBodyOfMethodIntoAnotherVisitor extends MethodVisitor {
 		private InsertBodyOfMethodIntoAnotherVisitor(MethodVisitor mv) {
-			super(Opcodes.ASM4, mv);
+			super(Opcodes.ASM6, mv);
 		}
 		
 		@Override public AnnotationVisitor visitParameterAnnotation(int parameter, String desc, boolean visible) { return null; }
@@ -235,18 +238,22 @@ public abstract class PatchScript {
 	 */
 	protected static class MethodPatcher extends ClassVisitor {
 		private List<TargetMatcher> targets = new ArrayList<TargetMatcher>();
-		private @Getter String ownClassSpec;
+		private String ownClassSpec;
 		private final MethodPatcherFactory factory;
 		private List<Hook> transplants = new ArrayList<Hook>();
 		private final TransplantMapper transplantMapper;
 		private int classFileFormatVersion;
 		
 		public MethodPatcher(ClassVisitor cv, TransplantMapper transplantMapper, MethodPatcherFactory factory) {
-			super(Opcodes.ASM4, cv);
+			super(Opcodes.ASM6, cv);
 			this.factory = factory;
 			this.transplantMapper = transplantMapper;
 		}
 		
+		public String getOwnClassSpec() {
+			return ownClassSpec;
+		}
+		
 		/**
 		 * The {@code factory} will be called for any methods that match any added target.
 		 */
